NDARE
=====

NDARE is currently under development.

Check out the official documentation: `https://ndare.readthedocs.io/en/latest <https://ndare.readthedocs.io/en/latest/>`_

Explore the open source code repository: `https://github.com/vitorinojoao/ndare <https://github.com/vitorinojoao/ndare>`_

Install it from the Python Package Index: `https://pypi.org/project/ndare <https://pypi.org/project/ndare/>`_
